@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.91 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: amenu.c,v 1.95 2009/08/28 00:40:00 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -780,9 +780,6 @@ void	set_menu_auto_mark( menu_t **dflt )
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	kk;
 
-		if( i == auto_mark_cur_n )
-			*dflt = &(p[k]);
-
 		if( (i != 0) && ((i % AUTO_MARK_N_PER_PAGE) == 0) ){
 			str_nz_cpy( p[k].path, "/auto mark/--",
 					MENU_PATH_MAX_LEN );
@@ -800,6 +797,9 @@ void	set_menu_auto_mark( menu_t **dflt )
 			key = 'A';
 		}
 
+		if( i == auto_mark_cur_n )
+			*dflt = &(p[k]);
+
 		kk = k;
 
 		if( ls_flg_ena_auto_mark[i] ){
@@ -1162,6 +1162,7 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 
 	/* 򥻥å */
 	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
+
 	/* 󥹥ޡ */
 	mark_mnstr( mbr, mnstr, dist );
 
@@ -1602,6 +1603,8 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 			str_goto = exec_menu(
 					ls_menu_auto_mark_edit,
 					NULL, NULL );
+			set_menu_auto_mark( dflt );
+
 			if( str_goto == NULL )
 				continue;
 			if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
@@ -2382,10 +2385,10 @@ char	*cb_menu_auto_mark_edit_macro_bind( menu_t **pp, menu_t **dflt )
 	/* ޥ桼 */
 
 	x = str_len_draw( msg_cmd );
-	y = get_max_line() - 1;
+	y = get_screen_row() - 1;
 	str_nz_cpy( buf_cmd, cmd, MACRO_MAX_LEN );
 
-	if( game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
+	if( game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, FALSE ) ){
 		long	len;
 
 		/* βԤ */
@@ -2653,6 +2656,8 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 			hint,
 			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
+	set_menu_auto_mark( dflt );
+
 	return "/auto mark";
 }
 
