@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.121 2009/01/31 11:25:27 bowkenken Exp $
+* $Id: chr.h,v 1.126 2009/08/28 05:40:11 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -68,12 +68,22 @@
 * ̾κʸ
 ***************************************************************/
 
-#define	CHR_NAME_MAX_LEN	80	/* 饯 */
-#define	MBR_NAME_MAX_LEN	16	/* С */
-#define	MNSTR_NAME_MAX_LEN	80	/* 󥹥 */
+/* 饯 */
+#define	CHR_NAME_MAX_LEN	80
+#define	CHR_NAME_MAX_BYTE	(CHR_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* С */
+#define	MBR_NAME_MAX_LEN	16
+#define	MBR_NAME_MAX_BYTE	(MBR_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* 󥹥 */
+#define	MNSTR_NAME_MAX_LEN	CHR_NAME_MAX_LEN
+#define	MNSTR_NAME_MAX_BYTE	CHR_NAME_MAX_BYTE
 
-#define	RACE_STR_MAX_LEN	32	/* ݤ碌ޤ᤿²̾ */
-#define	RACE_NAME_MAX_LEN	16	/* ²̾ */
+/* ݤ碌ޤ᤿²̾ */
+#define	RACE_STR_MAX_LEN	32
+#define	RACE_STR_MAX_BYTE	(RACE_STR_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* ²̾ */
+#define	RACE_NAME_MAX_LEN	16
+#define	RACE_NAME_MAX_BYTE	(RACE_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /***************************************************************
 * 饯ǽ
@@ -150,12 +160,20 @@ typedef unsigned long	flg_work_t;
 /* 󥹥˥ƥǤ */
 #define	FLG_WORK_STEAL_END	(1 << 1)
 
+/* 2x2 ʾΥ󥹥 1 ٤̵ͤˤե饰 */
+#define	FLG_WORK_BLAST_END	(1 << 2)
+
 /***************************************************************
 * 饹
 ***************************************************************/
 
-#define	CLASS_MAX_N	99	/*  */
-#define	CLASS_NAME_MAX_LEN	20	/* ̾κʸ */
+/*  */
+#define	CLASS_MAX_N	99
+
+/* ̾κʸ */
+#define	CLASS_NAME_MAX_LEN	20
+#define	CLASS_NAME_MAX_BYTE	\
+	(CLASS_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /***************************************************************
 * 󥫡
@@ -173,6 +191,7 @@ typedef unsigned long	flg_work_t;
 
 /* κʸ */
 #define	ACT_MSG_MAX_LEN	64
+#define	ACT_MSG_MAX_BYTE	(ACT_MSG_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* դĤΨ */
 #define	STAGGER_RATE_CHR_CONFUSION	((rate_t)70)	/*  */
@@ -230,7 +249,7 @@ typedef enum {
 typedef struct {
 	main_race_t	main;
 	sub_race_t	sub;
-	char	name[RACE_NAME_MAX_LEN + 1];
+	char	name[RACE_NAME_MAX_BYTE + 1];
 } race_t;
 
 /***************************************************************
@@ -458,7 +477,7 @@ typedef enum {
 typedef struct {
 	/* ̾ */
 	n_msg_t	n_name;
-	char	name[CLASS_NAME_MAX_LEN + 1];
+	char	name[CLASS_NAME_MAX_BYTE + 1];
 
 	/* ǥեȤΥ饹 */
 	class_dflt_t	dflt;
@@ -518,6 +537,7 @@ typedef enum {
 
 	/* ѡƥΥ */
 	ACT_KIND_SHOP,
+	ACT_KIND_TELEPORT_PARTY,
 	ACT_KIND_RECALL,
 	ACT_KIND_MAX_N,
 } act_kind_t;
@@ -532,11 +552,11 @@ typedef struct {
 	long	n, n2;
 
 	/* ɽʸ */
-	char	msg[ACT_MSG_MAX_LEN + 1];
+	char	msg[ACT_MSG_MAX_BYTE + 1];
 
 	act_kind_t	dflt_kind_mnstr;
 	/* ɽʸ */
-	char	dflt_msg_mnstr[ACT_MSG_MAX_LEN + 1];
+	char	dflt_msg_mnstr[ACT_MSG_MAX_BYTE + 1];
 } act_t;
 
 /***************************************************************
@@ -603,6 +623,8 @@ typedef enum {
 	ATTITUDE_NEUTRAL,
 	/* ŨŪ */
 	ATTITUDE_ENEMY,
+
+	ATTITUDE_MAX_N,
 } attitude_t;
 
 /***************************************************************
@@ -773,7 +795,7 @@ typedef struct chr_t {
 
 	/* μ */
 	chr_kind_t	kind;
-	char	name[CHR_NAME_MAX_LEN + 1];
+	char	name[CHR_NAME_MAX_BYTE + 1];
 
 	/* ԡɻ ID */
 	long	id1, id2;
