@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.82 2009/01/24 23:34:24 bowkenken Exp $
+* $Id: curs.c,v 1.87 2009/08/15 06:21:45 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,7 +40,11 @@
 ***************************************************************/
 
 static bool_t	g_flg_screen_size_auto;
-static long	g_screen_size_lines;
+static long	g_screen_size_col;
+static long	g_screen_size_row;
+static long	g_screen_size_message;
+static bool_t	g_flg_resize_map;
+check_memory_def( check_memory_curs_c_g_flg_screen_size_auto )
 
 /* ס󥹤Ȥäȿž°褹뤫? */
 #define	FLG_PRINT_REVERSE	0
@@ -51,6 +55,7 @@ static long	flg_curs, flg_curs_draw;
 static bool_t	flg_color;
 /* ߤ° */
 static curs_attr_t	g_current_attr;
+check_memory_def( check_memory_curs_c_flg_curs )
 
 /* °Υǥե */
 
@@ -139,6 +144,7 @@ static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 	{ 0, N_MSG_ATTR_ACID,
 		COLOR_YELLOW, COLOR_BLACK, A_BOLD, },
 };
+check_memory_def( check_memory_curs_c_g_curs_attr )
 
 /***************************************************************
 * 
@@ -147,7 +153,10 @@ static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
 void	init_curs( void )
 {
 	set_flg_screen_size_auto( TRUE );
-	set_screen_size_lines( 24 );
+	set_screen_size_col( 80 );
+	set_screen_size_row( 24 );
+	set_screen_size_message( 24 - (20 + 1) );
+	set_flg_resize_map( FALSE );
 
 	flg_curs = 0;
 	flg_curs_draw = 0;
@@ -388,7 +397,7 @@ void	curs_endwin( void )
 #endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_DOS
-		curs_move( get_max_line(), 0 );
+		curs_move( get_screen_row() - 1, 0 );
 #endif	/* D_DOS */
 
 	}
@@ -704,11 +713,11 @@ void	curs_move( int scrn_y, int scrn_x )
 {
 	if( scrn_x < SCREEN_MIN_X )
 		return;
-	if( scrn_x > SCREEN_MAX_X )
-		return;
 	if( scrn_y < SCREEN_MIN_Y )
 		return;
-	if( scrn_y > get_max_line() - 1 )
+	if( scrn_x > get_screen_col() - 1 )
+		return;
+	if( scrn_y > get_screen_row() - 1 )
 		return;
 
 #ifndef	D_DOS
@@ -801,7 +810,7 @@ void	curs_clear( void )
 
 	if( g_flg_cui ){
 		long	i;
-		const long	max_n = get_max_line();
+		const long	max_n = get_screen_row();
 
 		curs_move( 0, 0 );
 		for( i = 0; i < max_n; i++ )
@@ -902,17 +911,47 @@ bool_t	chk_color( void )
 }
 
 /***************************************************************
-* ̤κԿĴ٤
-* return : Կ
+* ̤βʸĴ٤
+* return : ʸ
 ***************************************************************/
 
-long	get_max_line( void )
+long	get_screen_col( void )
 {
 	if( !g_flg_cui )
-		return 1;
+		return SCREEN_WIDTH;
+
+#if	defined( HAVE_NCURSES_H ) || defined( HAVE_CURSES_H )
+	if( chk_curs() ){
+		return COLS;
+	}
+#endif
+
+#ifdef	D_DOS
+	{
+		CONSOLE_SCREEN_BUFFER_INFO cInfo;
+
+		GetConsoleScreenBufferInfo(
+				GetStdHandle( STD_OUTPUT_HANDLE ),
+				&cInfo );
+		return( cInfo.srWindow.Right - cInfo.srWindow.Left + 1 );
+	}
+#endif	/* D_DOS */
 
 	if( !chk_flg_screen_size_auto() )
-		return get_screen_size_lines();
+		return get_screen_size_col();
+
+	return SCREEN_WIDTH;
+}
+
+/***************************************************************
+* ̤νĹԿĴ٤
+* return : ĹԿ
+***************************************************************/
+
+long	get_screen_row( void )
+{
+	if( !g_flg_cui )
+		return SCREEN_HEIGHT;
 
 #if	defined( HAVE_NCURSES_H ) || defined( HAVE_CURSES_H )
 	if( chk_curs() ){
@@ -931,9 +970,79 @@ long	get_max_line( void )
 	}
 #endif	/* D_DOS */
 
+	if( !chk_flg_screen_size_auto() )
+		return get_screen_size_row();
+
 	return SCREEN_HEIGHT;
 }
 
+/***************************************************************
+* åβʸĴ٤
+* return : ʸ
+***************************************************************/
+
+long	get_message_col( void )
+{
+	return get_screen_col();
+}
+
+/***************************************************************
+* åνĹԿĴ٤
+* return : ĹԿ
+***************************************************************/
+
+long	get_message_row( void )
+{
+	if( chk_flg_resize_map() ){
+		return get_screen_size_message();
+	} else {
+		return( get_screen_row() - (WIN_MAP_DRAW_HEIGHT + 1) );
+	}
+
+	return 1;
+}
+
+/***************************************************************
+* ޥåפβʸĴ٤
+* return : ʸ
+***************************************************************/
+
+long	get_map_col( void )
+{
+	if( chk_flg_resize_map() ){
+		long	n;
+
+		n = WIN_MAP_DRAW_MAX_X + 1;
+		n = SCREEN_WIDTH - n;
+		n = get_screen_col() - n;
+		return n;
+	} else {
+		return( WIN_MAP_DRAW_MAX_X + 1 );
+	}
+
+	return 1;
+}
+
+/***************************************************************
+* ޥåפνĹԿĴ٤
+* return : ĹԿ
+***************************************************************/
+
+long	get_map_row( void )
+{
+	if( chk_flg_resize_map() ){
+		long	n;
+
+		n = get_screen_size_message() + 1;
+		n = get_screen_row() - n;
+		return n;
+	} else {
+		return( WIN_MAP_DRAW_MAX_Y + 1 );
+	}
+
+	return 1;
+}
+
 /***************************************************************
 * ̥μư꤬ͭĴ٤
 * return : ͭ?
@@ -958,28 +1067,101 @@ void	set_flg_screen_size_auto( bool_t flg )
 }
 
 /***************************************************************
-* ̤κԿ֤ͤ
-* return : Կ
+* ̤κ粣ʸ֤ͤ
+* return : 粣ʸ
 ***************************************************************/
 
-long	get_screen_size_lines( void )
+long	get_screen_size_col( void )
 {
-	return g_screen_size_lines;
+	return g_screen_size_col;
 }
 
 /***************************************************************
-* ̤κԿ
-* return : Կ
+* ̤κ粣ʸ
+* long n : 粣ʸ
 ***************************************************************/
 
-void	set_screen_size_lines( long n )
+void	set_screen_size_col( long n )
 {
-	if( n < SCREEN_SIZE_MIN_LINES )
-		n = SCREEN_SIZE_MIN_LINES;
-	if( n > SCREEN_SIZE_MAX_LINES )
-		n = SCREEN_SIZE_MAX_LINES;
+	if( n < SCREEN_SIZE_MIN_COL )
+		n = SCREEN_SIZE_MIN_COL;
+	if( n > SCREEN_SIZE_MAX_COL )
+		n = SCREEN_SIZE_MAX_COL;
 
-	g_screen_size_lines = n;
+	g_screen_size_col = n;
+}
+
+/***************************************************************
+* ̤κĹԿ֤ͤ
+* return : ĹԿ
+***************************************************************/
+
+long	get_screen_size_row( void )
+{
+	return g_screen_size_row;
+}
+
+/***************************************************************
+* ̤κĹԿ
+* long n : ĹԿ
+***************************************************************/
+
+void	set_screen_size_row( long n )
+{
+	if( n < SCREEN_SIZE_MIN_ROW )
+		n = SCREEN_SIZE_MIN_ROW;
+	if( n > SCREEN_SIZE_MAX_ROW )
+		n = SCREEN_SIZE_MAX_ROW;
+
+	g_screen_size_row = n;
+}
+
+/***************************************************************
+* ̤κåԿ֤ͤ
+* return : åԿ
+***************************************************************/
+
+long	get_screen_size_message( void )
+{
+	return g_screen_size_message;
+}
+
+/***************************************************************
+* ̤κåԿ
+* long n : åԿ
+***************************************************************/
+
+void	set_screen_size_message( long n )
+{
+	if( n < SCREEN_SIZE_MIN_ROW )
+		n = SCREEN_SIZE_MIN_ROW;
+	if( n > SCREEN_SIZE_MAX_ROW )
+		n = SCREEN_SIZE_MAX_ROW;
+
+	g_screen_size_message = n;
+}
+
+/***************************************************************
+* ޥåפΥѤĴ٤
+* return : Ѥ?
+***************************************************************/
+
+bool_t	chk_flg_resize_map( void )
+{
+	return g_flg_resize_map;
+}
+
+/***************************************************************
+* ޥåפΥѤꤹ
+* bool_t flg : Ѥ?
+***************************************************************/
+
+void	set_flg_resize_map( bool_t flg )
+{
+	if( flg )
+		g_flg_resize_map = TRUE;
+	else
+		g_flg_resize_map = FALSE;
 }
 
 /***************************************************************
@@ -1104,3 +1286,16 @@ int	attr_dos( curs_attr_t *attr )
 	return a;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_curs_c( void )
+{
+	check_memory( check_memory_curs_c_g_flg_screen_size_auto,
+			"curs.c: " );
+	check_memory( check_memory_curs_c_flg_curs,
+			"curs.c: " );
+	check_memory( check_memory_curs_c_g_curs_attr,
+			"curs.c: " );
+}
