@@ -135,7 +135,10 @@ char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
 char	*cb_menu_screen_size_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_screen_size_auto( menu_t **pp, menu_t **dflt );
-char	*cb_menu_screen_size_lines( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_col( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_row( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_message( menu_t **pp, menu_t **dflt );
+char	*cb_menu_screen_size_map( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
@@ -164,12 +167,17 @@ char	*cb_menu_set_key( menu_t **pp, menu_t **dflt );
 char	*cb_menu_set_key_reg_macro( menu_t **pp, menu_t **dflt );
 char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func( menu_t **pp, menu_t **dflt );
+char	*cb_menu_mouse( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
+long	get_func_draw_n( long n );
+char	*cb_menu_gui( menu_t **pp, menu_t **dflt );
+char	*cb_menu_move_crsr_dflt( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_music( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_kind_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_joystick_macro_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_kind( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user( menu_t **pp, menu_t **dflt );
@@ -225,6 +233,7 @@ menu_t	*get_ls_menu_move_crsr( void );
 flg_scroll_t	get_flg_scroll( void );
 flg_scroll_t	set_flg_scroll( flg_scroll_t flg );
 bool_t	get_flg_mbr_data_change_page_is_crsr( void );
+void	check_memory_imenu_c( void );
 
 #ifdef __cplusplus
 }
