@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.74 2009/06/24 10:44:14 bowkenken Exp $
+* $Id: last-boss.c,v 1.80 2009/09/04 19:10:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -35,6 +35,12 @@
 #define	LAST_BOSS_C
 #include	"inc.h"
 
+/***************************************************************
+* 
+***************************************************************/
+
+#define	FRAME_SKIP_MAX	4
+
 /***************************************************************
 * ѿ
 ***************************************************************/
@@ -57,6 +63,8 @@ static const long	XX_ENTER_WAIT = 3;
 static const long	XX_CORE_OFFSET_X = 0;
 static const long	XX_CORE_OFFSET_Y = 2;
 
+check_memory_def( check_memory_last_boss_c_EXEL_JUMP_MAX_Y )
+
 /***************************************************************
 * XX
 ***************************************************************/
@@ -67,6 +75,9 @@ static pos_t	xx_pos;
 static pos_t	g_core;
 static last_boss_ptn_t	last_boss_ptn_bg;
 static last_boss_ptn_t	last_boss_ptn_fg;
+static long	g_frame_skip;
+
+check_memory_def( check_memory_last_boss_c_xx_pos )
 
 /*  */
 
@@ -94,6 +105,8 @@ static last_boss_joint_t	*joint_hand_to_fore_arm_right;
 static last_boss_joint_t	*joint_hand_to_fore_arm_slap_left;
 static last_boss_joint_t	*joint_hand_to_fore_arm_slap_right;
 
+check_memory_def( check_memory_last_boss_c_joint_skull )
+
 static pos_t	pos_skull;
 static pos_t	pos_jaw;
 static pos_t	pos_jaw_open;
@@ -109,10 +122,14 @@ static pos_t	pos_hand_right;
 static pos_t	pos_hand_slap_left;
 static pos_t	pos_hand_slap_right;
 
+check_memory_def( check_memory_last_boss_c_pos_skull )
+
 static bool_t	flg_open_xx_jaw;
 static bool_t	flg_slap_xx_arm_left;
 static bool_t	flg_slap_xx_arm_right;
 
+check_memory_def( check_memory_last_boss_c_flg_open_xx_jaw )
+
 /***************************************************************
 * XX βǮ
 ***************************************************************/
@@ -120,8 +137,10 @@ static bool_t	flg_slap_xx_arm_right;
 /* δֳ */
 static const long	XX_HEAT_DY = 3;
 static const long	XX_HEAT_ANIME_N = 5;
+check_memory_def( check_memory_last_boss_c_XX_HEAT_DY )
 
 static const long	XX_HEAT_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_HEAT_WAIT_FRAME_N )
 
 static blast_t	xx_blast_heat[] = {
 	{
@@ -165,6 +184,7 @@ static blast_t	xx_blast_heat[] = {
 		},
 	},
 };
+check_memory_def( check_memory_last_boss_c_xx_blast_heat )
 
 /***************************************************************
 * XX ο乶
@@ -172,11 +192,13 @@ static blast_t	xx_blast_heat[] = {
 
 static const rate_t	XX_COLD_LASER_MAX_LEN = 10;
 static const rate_t	XX_COLD_LASER_ADD_LEN = 1;
+check_memory_def( check_memory_last_boss_c_XX_COLD_LASER_MAX_LEN )
 
 static const long	XX_COLD_BIT_WAIT_FRAME_N = 3;
 static const long	XX_COLD_NEXT_WAIT_FRAME_N = 30;
 static const long	XX_COLD_LASER_WAIT_FRAME_N = 3;
 static const long	XX_COLD_END_WAIT_FRAME_N = 60;
+check_memory_def( check_memory_last_boss_c_XX_COLD_BIT_WAIT_FRAME_N )
 
 static const char	*xx_laser[MBR_MAX_N] = {
 	"|",
@@ -186,6 +208,7 @@ static const char	*xx_laser[MBR_MAX_N] = {
 	"-",
 	"-",
 };
+check_memory_def( check_memory_last_boss_c_xx_laser )
 
 static pos_t	xx_laser_dxy[MBR_MAX_N] = {
 	{ +-0,  +1 },
@@ -195,6 +218,7 @@ static pos_t	xx_laser_dxy[MBR_MAX_N] = {
 	{  +1, +-0 },
 	{  -1, +-0 },
 };
+check_memory_def( check_memory_last_boss_c_xx_laser_dxy )
 
 static blast_t	xx_bit[MBR_MAX_N] = {
 	{
@@ -258,18 +282,22 @@ static blast_t	xx_bit[MBR_MAX_N] = {
 		},
 	},
 };
+check_memory_def( check_memory_last_boss_c_xx_bit )
 
 /***************************************************************
 * XX 
 ***************************************************************/
 
 static const rate_t	XX_MIND_ADD_RATE = 10;
+check_memory_def( check_memory_last_boss_c_XX_MIND_ADD_RATE )
 
 static const long	XX_MIND_ANIME_N = 5;
 static const long	XX_MIND_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_MIND_ANIME_N )
 
 static const char	*xx_refract_head = "**";
 static const char	*xx_refract_image = "oo";
+check_memory_def( check_memory_last_boss_c_xx_refract_head )
 
 static void xx_mind_refract( xx_mind_t *xx_mind );
 static void xx_mind_move( xx_mind_t *xx_mind );
@@ -282,8 +310,10 @@ static void xx_mind_draw( xx_mind_t *xx_mind );
 #define	XX_ACID_HOMING_V	(1.0 * XX_ACID_HOMING_FIX_POINT)
 
 static const double	XX_ACID_MAX_Q = 18.0;
+check_memory_def( check_memory_last_boss_c_XX_ACID_MAX_Q )
 
 static const long	XX_ACID_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N )
 
 static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
 	{ -0.1, -XX_ACID_HOMING_V },
@@ -293,10 +323,12 @@ static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
 	{ -XX_ACID_HOMING_V, +-0.0 },
 	{ +XX_ACID_HOMING_V, +-0.0 },
 };
+check_memory_def( check_memory_last_boss_c_xx_homing_bgn_v )
 
 static const char	*xx_homing_head = "OO";
 static const char	*xx_homing_image = "oo";
 static const char	*xx_homing_tail = "++";
+check_memory_def( check_memory_last_boss_c_xx_homing_head )
 
 static bool_t xx_acid_chk_end( xx_acid_t *xx_acid );
 static void xx_acid_move( xx_acid_t *xx_acid );
@@ -308,8 +340,10 @@ static void xx_acid_draw( xx_acid_t *xx_acid );
 
 static const long	XX_ROTATION_ANIME_N = 2;
 static const long	XX_ROTATION_WAIT_FRAME_N = 6;
+check_memory_def( check_memory_last_boss_c_XX_ROTATION_ANIME_N )
 
 static const char	*xx_rotation_str = "o";
+check_memory_def( check_memory_last_boss_c_xx_rotation_str )
 
 /***************************************************************
 * XX αƹ
@@ -317,8 +351,10 @@ static const char	*xx_rotation_str = "o";
 
 static const long	XX_WHIRL_ANIME_N = 2;
 static const long	XX_WHIRL_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_WHIRL_ANIME_N )
 
 static const char	*xx_whirl_str = "x";
+check_memory_def( check_memory_last_boss_c_xx_whirl_str )
 
 /***************************************************************
 * XX ƹ
@@ -326,14 +362,17 @@ static const char	*xx_whirl_str = "x";
 
 static const long	XX_FAN_ANIME_N = 2;
 static const long	XX_FAN_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_FAN_ANIME_N )
 
 static const char	*xx_fan_str = "*";
+check_memory_def( check_memory_last_boss_c_xx_fan_str )
 
 /***************************************************************
 * XX ʿǤ
 ***************************************************************/
 
 static const long	XX_SLAP_WAIT_FRAME_N = 60;
+check_memory_def( check_memory_last_boss_c_XX_SLAP_WAIT_FRAME_N )
 
 static attack_t	xx_attack_slap[] = {
 	{ ATTACK_KIND_XX_SLAP, 1, FALSE, TRUE,
@@ -349,6 +388,7 @@ static attack_t	xx_attack_slap[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_last_boss_c_xx_attack_slap )
 
 /***************************************************************
 * 
@@ -356,6 +396,8 @@ static attack_t	xx_attack_slap[] = {
 
 void	init_last_boss( void )
 {
+	g_frame_skip = 1;
+
 	flg_open_xx_jaw = FALSE;
 	flg_slap_xx_arm_left = FALSE;
 	flg_slap_xx_arm_right = FALSE;
@@ -776,10 +818,12 @@ void	draw_last_boss( void )
 		draw_words_xex( MSG_WORDS_LAST_BOSS_ENCOUNTER_XEX_10 );
 		draw_words_exel( MSG_WORDS_LAST_BOSS_ENCOUNTER_EXEL_1 );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_ENCOUNTER_EXELER_1 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_OUT:
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -802,6 +846,7 @@ void	draw_last_boss( void )
 	case LAST_SCENE_N_EXEL_CUT_OUT:
 		break;
 	case LAST_SCENE_N_EXEL_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -839,15 +884,16 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_EXELER_1 );
 		draw_words_exeler( MSG_WORDS_LAST_BOSS_EXELER_2 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_EXELER_CUT_OUT:
 		break;
 	case LAST_SCENE_N_EXELER_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_EXELER_ENTER:
-		set_vfx_wait( _100_PERCENT );
 		draw_exeler_enter();
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
@@ -887,15 +933,16 @@ void	draw_last_boss( void )
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_1 );
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_2 );
 		draw_words_xex( MSG_WORDS_LAST_BOSS_XEX_3 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_XEX_CUT_OUT:
 		break;
 	case LAST_SCENE_N_XEX_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_XX_ENTER:
-		set_vfx_wait( _100_PERCENT );
 		draw_xx_enter();
 		break;
 	case LAST_SCENE_N_XX_WORDS:
@@ -904,6 +951,7 @@ void	draw_last_boss( void )
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		draw_words_xx( MSG_WORDS_LAST_BOSS_XX_1 );
 		draw_words_xx( MSG_WORDS_LAST_BOSS_XX_2 );
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
@@ -1026,7 +1074,7 @@ void	draw_exel_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_ENTER_WAIT_FRAME_N );
+		wait_clock( EXEL_ENTER_WAIT_FRAME_N );
 	}
 
 	for( dy = EXEL_JUMP_MAX_Y; dy >= 0; dy-- ){
@@ -1041,7 +1089,7 @@ void	draw_exel_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_ENTER_WAIT_FRAME_N );
+		wait_clock( EXEL_ENTER_WAIT_FRAME_N );
 	}
 }
 
@@ -1075,7 +1123,7 @@ void	draw_exel_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_HYPER_NORMAL_WAIT_FRAME_N );
+		wait_clock( EXEL_HYPER_NORMAL_WAIT_FRAME_N );
 
 		/* 緿 */
 
@@ -1092,7 +1140,7 @@ void	draw_exel_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXEL_HYPER_PERFECT_WAIT_FRAME_N );
+		wait_clock( EXEL_HYPER_PERFECT_WAIT_FRAME_N );
 	}
 }
 
@@ -1161,7 +1209,7 @@ void	draw_exeler_enter( void )
 		draw_mnstr( p2 );
 		draw_mnstr( p3 );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_ENTER_WAIT_FRAME_N );
+		wait_clock( EXELER_ENTER_WAIT_FRAME_N );
 	}
 }
 
@@ -1195,7 +1243,7 @@ void	draw_exeler_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_HYPER_NORMAL_WAIT_FRAME_N );
+		wait_clock( EXELER_HYPER_NORMAL_WAIT_FRAME_N );
 
 		/* 緿 */
 
@@ -1212,7 +1260,7 @@ void	draw_exeler_hyper( void )
 
 		draw_mnstr( p );
 		call_pcg_dun_draw_turn( FALSE );
-		wait_frame( EXELER_HYPER_PERFECT_WAIT_FRAME_N );
+		wait_clock( EXELER_HYPER_PERFECT_WAIT_FRAME_N );
 	}
 }
 
@@ -1728,10 +1776,10 @@ void	draw_xex_earthquake( pos_t *draw, pos_t base_draw )
 		x = 0;
 	if( y < 0 )
 		y = 0;
-	if( x > MAP_MAX_X - WIN_MAP_WIDTH )
-		x = MAP_MAX_X - WIN_MAP_WIDTH;
-	if( y > MAP_MAX_Y - WIN_MAP_HEIGHT )
-		y = MAP_MAX_Y - WIN_MAP_HEIGHT;
+	if( x > MAP_MAX_X - (get_map_col() / 2) )
+		x = MAP_MAX_X - (get_map_col() / 2);
+	if( y > MAP_MAX_Y - get_map_row() )
+		y = MAP_MAX_Y - get_map_row();
 
 	draw->x = x;
 	draw->y = y;
@@ -2486,7 +2534,7 @@ pos_t	get_xx_pos( void )
 void	wait_frame_gui( long frame )
 {
 	if( g_flg_gui )
-		wait_frame( frame );
+		wait_100_n_msec( 5 );
 }
 
 /***************************************************************
@@ -2508,6 +2556,15 @@ void	act_mnstr_xx( mnstr_t *p )
 	pty = get_party();
 	kind = (xx_act_kind_t)(randm( XX_ACT_KIND_MAX_N - 1 ) + 1);
 
+	g_frame_skip = FRAME_SKIP_MAX
+			* (_100_PERCENT - get_vfx_wait())
+			/ _100_PERCENT
+			+ 1;
+	if( g_frame_skip < 1 )
+		g_frame_skip = 1;
+	if( g_frame_skip > FRAME_SKIP_MAX )
+		g_frame_skip = FRAME_SKIP_MAX;
+
 #if	0
 	if( g_flg_debug )
 		kind = XX_ACT_KIND_SLAP;
@@ -2692,7 +2749,8 @@ void	xx_act_heat_draw( mnstr_t *p )
 			break;
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		if( (xx_heat.head_y % XX_HEAT_DY) == 0 ){
 			n = (xx_heat.head_y / XX_HEAT_DY) % XX_HEAT_MAX_N;
@@ -2711,20 +2769,24 @@ void	xx_act_heat_draw( mnstr_t *p )
 			if( m >= blast_max_n )
 				continue;
 
-			draw_blast_cui( CHR_KIND_MBR,
-					xx_heat.blast_x[n],
-					xx_heat.blast_y[n],
-					&(xx_blast_heat[m]),
-					"XX" );
+			if( (i % g_frame_skip) == 0 ){
+				draw_blast_cui( CHR_KIND_MBR,
+						xx_heat.blast_x[n],
+						xx_heat.blast_y[n],
+						&(xx_blast_heat[m]),
+						"XX" );
+			}
 
 			xx_heat.blast_n[n]++;
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_HEAT, &xx_heat );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_HEAT, &xx_heat );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_HEAT_WAIT_FRAME_N );
+			wait_clock( XX_HEAT_WAIT_FRAME_N );
+		}
 
 		xx_heat.head_y++;
 	}
@@ -2809,15 +2871,18 @@ void	xx_act_cold_draw( mnstr_t *p )
 
 		flg_next = TRUE;
 		for( n = 0; n < MBR_MAX_N; n++ ){
+			long	d;
+
 			if( !clip_pos( xx_cold.bit_mx[n],
 					xx_cold.bit_my[n] ) ){
 				continue;
 			}
 
-			xx_cold.bit_x[n] += sgn_l( xx_cold.bit_mx[n]
-					- xx_cold.bit_x[n] );
-			xx_cold.bit_y[n] += sgn_l( xx_cold.bit_my[n]
-					- xx_cold.bit_y[n] );
+			d = sgn_l( xx_cold.bit_mx[n] - xx_cold.bit_x[n] );
+			xx_cold.bit_x[n] += d;
+
+			d = sgn_l( xx_cold.bit_my[n] - xx_cold.bit_y[n] );
+			xx_cold.bit_y[n] += d;
 
 			if( xx_cold.bit_x[n] != xx_cold.bit_mx[n] )
 				flg_next = FALSE;
@@ -2831,23 +2896,26 @@ void	xx_act_cold_draw( mnstr_t *p )
 					NULL );
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_COLD, &xx_cold );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_COLD, &xx_cold );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_COLD_BIT_WAIT_FRAME_N );
+			wait_clock( XX_COLD_BIT_WAIT_FRAME_N );
+		}
 
 		if( flg_next )
 			break;
 	}
 
-	wait_frame( XX_COLD_NEXT_WAIT_FRAME_N );
+	wait_clock( XX_COLD_NEXT_WAIT_FRAME_N );
 
 	/* 졼ȯͤ */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		for( n = 0; n < MBR_MAX_N; n++ ){
 			if( !clip_pos( xx_cold.bit_mx[n],
@@ -2878,25 +2946,29 @@ void	xx_act_cold_draw( mnstr_t *p )
 			}
 			curs_attrset_dflt();
 
-			draw_blast_cui( CHR_KIND_NULL,
-					xx_cold.bit_x[n],
-					xx_cold.bit_y[n],
-					&(xx_bit[n]),
-					NULL );
+			if( (i % g_frame_skip) == 0 ){
+				draw_blast_cui( CHR_KIND_NULL,
+						xx_cold.bit_x[n],
+						xx_cold.bit_y[n],
+						&(xx_bit[n]),
+						NULL );
+			}
 		}
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_COLD, &xx_cold );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_COLD, &xx_cold );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_COLD_LASER_WAIT_FRAME_N );
+			wait_clock( XX_COLD_LASER_WAIT_FRAME_N );
+		}
 
 		xx_cold.laser_len += XX_COLD_LASER_ADD_LEN;
 		if( xx_cold.laser_len > XX_COLD_LASER_MAX_LEN )
 			break;
 	}
 
-	wait_frame( XX_COLD_END_WAIT_FRAME_N );
+	wait_clock( XX_COLD_END_WAIT_FRAME_N );
 }
 
 /***************************************************************
@@ -2958,7 +3030,8 @@ void	xx_act_mind_draw( mnstr_t *p )
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		/* ư */
 
@@ -2971,13 +3044,16 @@ void	xx_act_mind_draw( mnstr_t *p )
 		}
 
 		xx_mind_move( &xx_mind );
-		xx_mind_draw( &xx_mind );
+		if( (i % g_frame_skip) == 0 )
+			xx_mind_draw( &xx_mind );
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_MIND, &xx_mind );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_MIND, &xx_mind );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_MIND_WAIT_FRAME_N );
+			wait_clock( XX_MIND_WAIT_FRAME_N );
+		}
 
 		xx_mind.rate += XX_MIND_ADD_RATE;
 		xx_mind.refract_idx++;
@@ -3173,19 +3249,23 @@ void	xx_act_acid_draw( mnstr_t *p )
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		if( xx_acid_chk_end( &xx_acid ) )
 			break;
 
 		xx_acid_move( &xx_acid );
-		xx_acid_draw( &xx_acid );
+		if( (i % g_frame_skip) == 0 )
+			xx_acid_draw( &xx_acid );
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_ACID, &xx_acid );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_ACID, &xx_acid );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_ACID_WAIT_FRAME_N );
+			wait_clock( XX_ACID_WAIT_FRAME_N );
+		}
 
 		xx_acid.homing_idx++;
 		xx_acid.homing_idx %= XX_ACID_IMAGE_MAX_N;
@@ -3443,7 +3523,8 @@ void	xx_act_rotation_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_COLD );
 		for( r = 0; r < XX_ROTATION_RING_MAX_N; r++ ){
@@ -3471,11 +3552,14 @@ void	xx_act_rotation_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_PARALYZE, &xx_rotation );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_PARALYZE,
+					&xx_rotation );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_ROTATION_WAIT_FRAME_N );
+			wait_clock( XX_ROTATION_WAIT_FRAME_N );
+		}
 
 		sg = +1;
 		for( r = 0; r < XX_ROTATION_RING_MAX_N; r++ ){
@@ -3609,7 +3693,8 @@ void	xx_act_whirl_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_HEAT );
 		for( n = 0; n < XX_WHIRL_MAX_N; n++ ){
@@ -3632,11 +3717,13 @@ void	xx_act_whirl_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_POISON, &xx_whirl );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_POISON, &xx_whirl );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_WHIRL_WAIT_FRAME_N );
+			wait_clock( XX_WHIRL_WAIT_FRAME_N );
+		}
 
 		/* ȯ */
 
@@ -3749,7 +3836,8 @@ void	xx_act_fan_draw( mnstr_t *p )
 		}
 
 		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
-			redraw_map();
+			if( (i % g_frame_skip) == 0 )
+				redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_MIND );
 		for( n = 0; n < XX_FAN_MAX_N; n++ ){
@@ -3777,11 +3865,13 @@ void	xx_act_fan_draw( mnstr_t *p )
 		}
 		curs_attrset_dflt();
 
-		call_pcg_dun_set_xx_attack(
-				XX_ACT_KIND_SLEEP, &xx_fan );
-		call_pcg_dun_draw_turn( TRUE );
+		if( (i % g_frame_skip) == 0 ){
+			call_pcg_dun_set_xx_attack(
+					XX_ACT_KIND_SLEEP, &xx_fan );
+			call_pcg_dun_draw_turn( TRUE );
 
-		wait_frame( XX_FAN_WAIT_FRAME_N );
+			wait_clock( XX_FAN_WAIT_FRAME_N );
+		}
 
 		/* ư */
 
@@ -3862,12 +3952,76 @@ void	xx_act_slap( mnstr_t *p )
 void	xx_act_slap_draw( mnstr_t *p )
 {
 	set_slap_xx_arm_left( TRUE );
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
 	set_slap_xx_arm_left( FALSE );
 
 	set_slap_xx_arm_right( TRUE );
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
 	set_slap_xx_arm_right( FALSE );
 
-	wait_frame( XX_SLAP_WAIT_FRAME_N );
+	wait_clock( XX_SLAP_WAIT_FRAME_N );
+}
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_last_boss_c( void )
+{
+	check_memory( check_memory_last_boss_c_EXEL_JUMP_MAX_Y,
+			"last-boss.c: EXEL_JUMP_MAX_Y" );
+	check_memory( check_memory_last_boss_c_xx_pos,
+			"last-boss.c: xx_pos" );
+	check_memory( check_memory_last_boss_c_joint_skull,
+			"last-boss.c: joint_skull" );
+	check_memory( check_memory_last_boss_c_pos_skull,
+			"last-boss.c: pos_skull" );
+	check_memory( check_memory_last_boss_c_flg_open_xx_jaw,
+			"last-boss.c: flg_open_xx_jaw" );
+	check_memory( check_memory_last_boss_c_XX_HEAT_DY,
+			"last-boss.c: XX_HEAT_DY" );
+	check_memory( check_memory_last_boss_c_XX_HEAT_WAIT_FRAME_N,
+			"last-boss.c: XX_HEAT_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_blast_heat,
+			"last-boss.c: xx_blast_heat" );
+	check_memory( check_memory_last_boss_c_XX_COLD_LASER_MAX_LEN,
+			"last-boss.c: XX_COLD_LASER_MAX_LEN" );
+	check_memory( check_memory_last_boss_c_XX_COLD_BIT_WAIT_FRAME_N,
+			"last-boss.c: XX_COLD_BIT_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_laser,
+			"last-boss.c: xx_laser" );
+	check_memory( check_memory_last_boss_c_xx_laser_dxy,
+			"last-boss.c: xx_laser_dxy" );
+	check_memory( check_memory_last_boss_c_xx_bit,
+			"last-boss.c: xx_bit" );
+	check_memory( check_memory_last_boss_c_XX_MIND_ADD_RATE,
+			"last-boss.c: XX_MIND_ADD_RATE" );
+	check_memory( check_memory_last_boss_c_XX_MIND_ANIME_N,
+			"last-boss.c: XX_MIND_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_refract_head,
+			"last-boss.c: xx_refract_head" );
+	check_memory( check_memory_last_boss_c_XX_ACID_MAX_Q,
+			"last-boss.c: XX_ACID_MAX_Q" );
+	check_memory( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N,
+			"last-boss.c: XX_ACID_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_homing_bgn_v,
+			"last-boss.c: xx_homing_bgn_v" );
+	check_memory( check_memory_last_boss_c_xx_homing_head,
+			"last-boss.c: xx_homing_head" );
+	check_memory( check_memory_last_boss_c_XX_ROTATION_ANIME_N,
+			"last-boss.c: XX_ROTATION_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_rotation_str,
+			"last-boss.c: xx_rotation_str" );
+	check_memory( check_memory_last_boss_c_XX_WHIRL_ANIME_N,
+			"last-boss.c: XX_WHIRL_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_whirl_str,
+			"last-boss.c: xx_whirl_str" );
+	check_memory( check_memory_last_boss_c_XX_FAN_ANIME_N,
+			"last-boss.c: XX_FAN_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_fan_str,
+			"last-boss.c: xx_fan_str" );
+	check_memory( check_memory_last_boss_c_XX_SLAP_WAIT_FRAME_N,
+			"last-boss.c: XX_SLAP_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_attack_slap,
+			"last-boss.c: xx_attack_slap" );
 }
