@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.50 2009/02/01 22:21:26 bowkenken Exp $
+* $Id: menu.h,v 1.52 2009/08/15 04:45:56 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -76,6 +76,7 @@
 
 /* ܤκʸ */
 #define	MENU_MAX_LEN	(SCREEN_WIDTH - 4)
+#define	MENU_MAX_BYTE	(MENU_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ڡκܿ */
 #define	MENU_MAX_N_PER_PAGE	18
@@ -103,7 +104,7 @@
 	| FLG_MENU_CHK_ON | FLG_MENU_CHK_OFF)
 
 /* ˥塼ѥκʸ */
-#define	MENU_PATH_MAX_LEN	64
+#define	MENU_PATH_MAX_LEN	80
 
 /* ܤμκʸ */
 #define	MENU_KIND_MAX_LEN	16
@@ -115,7 +116,8 @@
 #define	MENU_SHORT_KEY_MAX_LEN	16
 
 /* ܤκʸ */
-#define	MENU_MSG_MAX_LEN	(80 * 6 / 2)
+#define	MENU_MSG_MAX_LEN	80
+#define	MENU_MSG_MAX_BYTE	(MENU_MSG_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /**** ֡ ****/
 
@@ -150,43 +152,6 @@ typedef unsigned long	flg_scroll_t;
 #define	FLG_SCROLL_SMOOTH	(1 << 0)
 #define	FLG_SCROLL_CENTER	(1 << 1)
 
-/**** ե󥯥󡦥 ****/
-
-/* ե󥯥󡦥κ */
-#define	FUNC_KEY_MAX	80
-
-/**** ޥ⡼бե󥯥󡦥 ****/
-
-typedef enum {
-	FUNC_N_CLICK_L = 21,
-	FUNC_N_CLICK_M,
-	FUNC_N_CLICK_R,
-	FUNC_N_CLICK_0 = FUNC_N_CLICK_L,
-
-	FUNC_N_DBL_CLICK_L = 31,
-	FUNC_N_DBL_CLICK_M,
-	FUNC_N_DBL_CLICK_R,
-	FUNC_N_DBL_CLICK_0 = FUNC_N_DBL_CLICK_L,
-
-	FUNC_N_PRESS_L_CLICK_R = 41,
-	FUNC_N_PRESS_R_CLICK_L,
-
-	FUNC_N_PRESS_L = 51,
-	FUNC_N_PRESS_M,
-	FUNC_N_PRESS_R,
-	FUNC_N_PRESS_0 = FUNC_N_PRESS_L,
-
-	FUNC_N_RELEASE_L = 61,
-	FUNC_N_RELEASE_M,
-	FUNC_N_RELEASE_R,
-	FUNC_N_RELEASE_0 = FUNC_N_RELEASE_L,
-
-	FUNC_N_MOTION_LEFT = 71,
-	FUNC_N_MOTION_RIGHT,
-	FUNC_N_MOTION_UP,
-	FUNC_N_MOTION_DOWN,
-} func_n_t;
-
 /***************************************************************/
 
 /* ˥塼 */
@@ -204,7 +169,7 @@ typedef struct menu_t {
 
 	/* ̾ */
 	n_msg_t	n_msg;
-	char	msg[MENU_MSG_MAX_LEN + 1];
+	char	msg[MENU_MSG_MAX_BYTE + 1];
 
 	/* 롦Хåؿ */
 	menu_call_back_t	call_back;
