@@ -126,7 +126,7 @@ void	set_flg_no_save( bool_t flg );
 bool_t	get_flg_no_save( void );
 bool_t	exec_menu_identify_item( mbr_t *mbr );
 char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt );
-char	*cb_menu_identify_item_unknown( menu_t **pp, menu_t **dflt );
+char	*cb_menu_identify_item_no_sel( menu_t **pp, menu_t **dflt );
 bool_t	exec_menu_resurrection( mbr_t *mbr );
 char	*cb_menu_resurrection( menu_t **pp, menu_t **dflt );
 menu_t	*get_ls_menu_main( void );
@@ -140,6 +140,7 @@ pos_t	*get_sub_crsr( void );
 pos_t	*get_pre_sub_crsr( void );
 long	get_sel_mbr_n( void );
 void	set_sel_mbr_n( long n );
+void	check_memory_mmenu_c( void );
 
 #ifdef __cplusplus
 }
