@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.31 2009/07/23 11:58:15 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.33 2009/09/05 12:18:10 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -382,6 +382,10 @@ bool_t	set_act_tame_mnstr( mnstr_t *p )
 
 bool_t	set_act_rescue_trgt( mnstr_t *p )
 {
+	bool_t	flg_find;
+
+	/* ߽оݤå */
+
 	if( p == NULL )
 		return FALSE;
 	if( p->work.request == NULL )
@@ -389,17 +393,20 @@ bool_t	set_act_rescue_trgt( mnstr_t *p )
 	if( p->work.request->kind != REQUEST_KIND_RESCUE )
 		return FALSE;
 
-	if( chk_flg_work_find_mbr( p ) )
-		return FALSE;
+	/* ߽о */
 
-	mnstr_mark_mbr_std( p );
+	flg_find = chk_flg_work_find_mbr( p );
 
-	if( !chk_flg_work_find_mbr( p ) )
-		return TRUE;
+	set_chr_act( p, ACT_KIND_MBR_TAIL, NULL, NULL, 0, 0 );
+	if( is_pet( p ) )
+		mark_mnstr( p, (mnstr_t *)(p->owner->trgt.p), DIST_NEAR );
+	else
+		mnstr_mark_mbr_std( p );
 
-	/* ߽λ */
-
-	chk_finish_request_join( p->work.request, p );
+	if( !flg_find && chk_flg_work_find_mbr( p ) ){
+		/* ߽λ */
+		chk_finish_request_join( p->work.request, p );
+	}
 
 	return TRUE;
 }
