@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.229 2009/07/23 15:54:39 bowkenken Exp $
+* $Id: mnstr.c,v 1.230 2009/09/03 01:57:50 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -57,6 +57,9 @@
 /*  */
 #define	GROUP_RATE_BASE	50
 
+/* 󥹥֤ޤϼʬ˲ʸ򾧤 HP κΨ */
+#define	MNSTR_SPELL_FRIEND_HP_RATE	70
+
 /***************************************************************
 * 󥹥Υǡ
 ***************************************************************/
@@ -1181,6 +1184,8 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 			&& (p->trgt.kind != TRGT_KIND_MNSTR) ){
 		return FALSE;
 	}
+	if( p->trgt.p == NULL )
+		return FALSE;
 
 	trgt = (chr_t *)(p->trgt.p);
 	ls = p->mnstr_tab->attack;
@@ -1209,10 +1214,13 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 
 		set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 	} else {
+		bool_t	flg_cast;
 		attack_t	*atk;
 		long	d;
 		chr_t	*friend_chr;
 
+		flg_cast = TRUE;
+
 		d = max_l( labs( p->x - trgt->x ), labs( p->y - trgt->y ) );
 		atk = get_attack( FALSE, ls, d,
 				FALSE, FALSE, FALSE, TRUE );
@@ -1226,20 +1234,25 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 		else
 			friend_chr = NULL;
 
-		if( friend_chr != NULL ){
+		if( friend_chr == NULL ){
+			if( !chk_find_chr( p, trgt ) )
+				flg_cast = FALSE;
+		} else {
 			rate_t	rate;
 
 			rate = friend_chr->abl.hp.n * _100_PERCENT
 					/ friend_chr->abl.hp.max;
-			if( rate < 70 ){
+
+			if( (rate <= MNSTR_SPELL_FRIEND_HP_RATE)
+					&& chk_find_chr( p, friend_chr ) ){
 				trgt = friend_chr;
 				mark_mnstr( p, friend_chr, DIST_FAR );
 			} else {
-				friend_chr = NULL;
+				flg_cast = FALSE;
 			}
 		}
 
-		if( (friend_chr != NULL) && chk_find_chr( p, friend_chr ) ){
+		if( flg_cast ){
 			set_chr_act( p, ACT_KIND_SPELL,
 					get_spell_tab( atk->spell ),
 					MSG( atk->spell_fmt ),
