@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.238 2009/07/04 08:01:54 bowkenken Exp $
+* $Id: party.c,v 1.239 2009/07/23 15:54:39 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -3135,15 +3135,7 @@ mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
 			tmp_n = p->abl.mp.n;
 		}
 
-		if( (min_max >= +1) && (tmp_rate > min_max_rate) ){
-			min_max_rate = tmp_rate;
-			min_max_n = tmp_n;
-			n = 1;
-		} else if( (min_max <= -1) && (tmp_rate < min_max_rate) ){
-			min_max_rate = tmp_rate;
-			min_max_n = tmp_n;
-			n = 1;
-		} else if( tmp_rate == min_max_rate ){
+		if( tmp_rate == min_max_rate ){
 			if( (min_max >= +1) && (tmp_n > min_max_n) ){
 				min_max_rate = tmp_rate;
 				min_max_n = tmp_n;
@@ -3163,6 +3155,14 @@ mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
 			} else {
 				continue;
 			}
+		} else if( (min_max >= +1) && (tmp_rate > min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( (min_max <= -1) && (tmp_rate < min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
 		} else {
 			continue;
 		}
