@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: scene.h,v 1.14 2008/10/06 23:03:31 bowkenken Exp $
+* $Id: scene.h,v 1.19 2009/07/31 19:01:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SCENE_H
@@ -60,6 +60,7 @@ typedef enum {
 	SCENE_N_ENDING,
 	SCENE_N_ENDING_EPILOGUE,
 	SCENE_N_ENDING_SPACE,
+	SCENE_N_ENDING_STAFF_ROLL,
 	SCENE_N_ENDING_END,
 
 	SCENE_N_SEL_MBR_GRAPH,
@@ -67,6 +68,30 @@ typedef enum {
 	SCENE_N_MAX_N,
 } scene_n_t;
 
+typedef enum {
+	SCENE_GROUP_N_NULL,
+
+	SCENE_GROUP_N_INIT,
+	SCENE_GROUP_N_TITLE,
+
+	SCENE_GROUP_N_PLAYING,
+	SCENE_GROUP_N_BATTLE,
+
+	SCENE_GROUP_N_GAME_OVER,
+	SCENE_GROUP_N_ENDING,
+	SCENE_GROUP_N_SPACE,
+	SCENE_GROUP_N_GAME_END,
+
+	SCENE_GROUP_N_SEL_GRAPH,
+
+	SCENE_GROUP_N_DEMO,
+
+	SCENE_GROUP_N_CAN_SKIP,
+	SCENE_GROUP_N_CAN_NOT_SKIP,
+
+	SCENE_GROUP_N_MAX_N,
+} scene_group_n_t;
+
 typedef enum {
 	LAST_SCENE_N_NULL,
 
@@ -104,32 +129,14 @@ typedef enum {
 	LAST_SCENE_N_XEX_CUT_OUT,
 	LAST_SCENE_N_XEX_CUT_END,
 
+	LAST_SCENE_N_XX_ENTER,
+	LAST_SCENE_N_XX_WORDS,
+	LAST_SCENE_N_XX_BATTLE,
+	LAST_SCENE_N_XX_DIE,
+
 	LAST_SCENE_N_END,
 
 	LAST_SCENE_N_MAX_N,
 } last_scene_n_t;
 
-typedef enum {
-	SCENE_GROUP_N_NULL,
-
-	SCENE_GROUP_N_INIT,
-	SCENE_GROUP_N_TITLE,
-
-	SCENE_GROUP_N_PLAYING,
-	SCENE_GROUP_N_BATTLE,
-
-	SCENE_GROUP_N_GAME_OVER,
-	SCENE_GROUP_N_ENDING,
-	SCENE_GROUP_N_GAME_END,
-
-	SCENE_GROUP_N_SEL_GRAPH,
-
-	SCENE_GROUP_N_DEMO,
-
-	SCENE_GROUP_N_CAN_SKIP,
-	SCENE_GROUP_N_CAN_NOT_SKIP,
-
-	SCENE_GROUP_N_MAX_N,
-} scene_group_n_t;
-
 #endif	/* SCENE_H */
