@@ -10,8 +10,11 @@ void	init_spell_debug( void );
 void	init_spell_new_mbr( long ls_mbr_n );
 void	init_spell_dflt( void );
 void	init_spell_nin( void );
+void	reset_spell( void );
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt );
 char	*menu_sel_spell( mbr_t *mbr );
+char	*cb_menu_reg_spell( menu_t **pp, menu_t **dflt );
+char	*cb_menu_reg_spell_remark( menu_t **pp, menu_t **dflt );
 char	*cb_menu_dflt_spell_mag( menu_t **pp, menu_t **dflt );
 char	*cb_menu_dflt_spell_sor( menu_t **pp, menu_t **dflt );
 char	*cb_menu_dflt_spell_enc( menu_t **pp, menu_t **dflt );
@@ -24,6 +27,7 @@ char	*menu_dflt_spell( menu_t **pp, menu_t **dflt, abl_kind_t kind );
 char	*cb_menu_spell_no_learn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_spell( menu_t **pp, menu_t **dflt );
 char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt );
+bool_t	get_spell_flg_trgt( spell_tab_t *tab, extent_kind_t ex );
 char	*menu_spell_trgt( mbr_t *mbr );
 void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt );
 void	play_sound_spell( chr_t *chr, spell_kind_t kind );
@@ -78,6 +82,14 @@ void	counter_magic(
 	spell_tab_t *tab, rate_t rate,
 	long x, long y, trgt_kind_t trgt_kind, void *p
 );
+reg_spell_t	*get_reg_spell( long mbr_n );
+void	set_reg_spell(
+	long mbr_n,
+	spell_tab_t *tab,
+	extent_kind_t extent_kind,
+	trgt_t trgt
+);
+void	lost_trgt_reg_spell( void *p );
 bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item );
 bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt );
 fx_kind_t	cv_spell_to_fx( spell_kind_t spell );
