@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.17 2008/02/14 08:44:16 bowkenken Exp $
+* $Id: spell-tab.h,v 1.22 2009/09/04 11:35:11 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -52,6 +52,26 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+/* ʸϿ */
+	{
+		"/spell/reg spell",
+		"<Item>",
+		ACCEL_KEY_REG_SPELL,
+		"",
+		N_MSG_NULL, "",
+		cb_menu_reg_spell, NULL,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/reg spell remark",
+		"<OpenWinItem>",
+		ACCEL_KEY_REG_SPELL_REMARK,
+		"",
+		N_MSG_NULL, "",
+		cb_menu_reg_spell_remark, NULL,
+		FLG_NULL,
+	},
 /* [ˡ] */
 	{
 		"/spell/MAG",
@@ -163,26 +183,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/MAG/dispel_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DISPEL_MAGIC, "",
-		cb_menu_spell, (void *)SPELL_KIND_DISPEL_MAGIC,
-		FLG_NULL,
-	},
-
-	{
-		"/spell/MAG/mirror_image",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MIRROR_IMAGE, "",
-		cb_menu_spell, (void *)SPELL_KIND_MIRROR_IMAGE,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/MAG/animate_objects",
 		"<Branch>",
@@ -216,7 +216,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -346,7 +346,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn detect",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -423,6 +423,26 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/MAG/dispel_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISPEL_MAGIC, "",
+		cb_menu_spell, (void *)SPELL_KIND_DISPEL_MAGIC,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/MAG/mirror_image",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MIRROR_IMAGE, "",
+		cb_menu_spell, (void *)SPELL_KIND_MIRROR_IMAGE,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/MAG/polymorph_other",
 		"<Branch>",
@@ -456,7 +476,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn change status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -585,7 +605,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn attack",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -675,7 +695,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn defense",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -805,7 +825,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn weaken status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -905,7 +925,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn strengthen ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -955,7 +975,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn strengthen misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1045,7 +1065,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn weaken ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1115,7 +1135,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn weaken misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1235,7 +1255,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SUM/no_learn summon",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1375,7 +1395,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn cure",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1492,6 +1512,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/PRI/cure_hallucination",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_CURE_HALLUCINATION, "",
+		cb_menu_spell, (void *)SPELL_KIND_CURE_HALLUCINATION,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/PRI/cure_charm",
 		"<Branch>",
@@ -1505,7 +1535,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn cure status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1615,7 +1645,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn resist",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1705,7 +1735,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn holy",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1805,7 +1835,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SHA/no_learn weak elemental",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1842,16 +1872,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_salamander",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_SALAMANDER, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SALAMANDER,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_water_elemental",
 		"<Branch>",
@@ -1862,16 +1882,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_undine",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_UNDINE, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_UNDINE,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_air_elemental",
 		"<Branch>",
@@ -1882,16 +1892,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_sylph",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_SYLPH, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SYLPH,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_earth_elemental",
 		"<Branch>",
@@ -1902,16 +1902,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_gnome",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_GNOME, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_GNOME,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_will_o_wisp",
 		"<Branch>",
@@ -1932,10 +1922,60 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/SHA/summon_salamander",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_SALAMANDER, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SALAMANDER,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_undine",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_UNDINE, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_UNDINE,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_sylph",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_SYLPH, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SYLPH,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_gnome",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_GNOME, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_GNOME,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/dismissal_elemental",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISMISSAL_ELEMENTAL, "",
+		cb_menu_spell, (void *)SPELL_KIND_DISMISSAL_ELEMENTAL,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/SHA/no_learn summon elemental",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1995,7 +2035,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn cure",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2085,7 +2125,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn strengthen ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2175,7 +2215,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn weaken ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2315,7 +2355,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn resist status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2405,7 +2445,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/NIN/no_learn disaster",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2485,7 +2525,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/NIN/no_learn misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2501,7 +2541,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/*  */
+/**/
 	{
 		"",
 		"",
