@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.205 2009/08/08 21:02:29 bowkenken Exp $
+* $Id: spell.c,v 1.209 2009/09/04 11:35:11 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -33,10 +33,6 @@
 
 /**/
 
-#include	"spell-tab.h"
-
-/**/
-
 /* ξǵʳȤɤ? */
 #define	FLG_SPELL_SANCTUARY	TRUE
 
@@ -60,7 +56,11 @@
 #define	SPELL_NIN_RATE	((rate_t)80)
 #define	SPELL_SHA_RESI_DIV_RATE	((rate_t)400)
 
-#define	BAR_LIMIT_LEV	10
+#define	BAR_LIMIT_LEV	30
+
+#define	ACCEL_KEY_REG_SPELL	'X'
+#define	ACCEL_KEY_REG_SPELL_REMARK	'Y'
+#define	ACCEL_KEY_NO_LEARN	'Z'
 
 /**/
 
@@ -87,6 +87,15 @@ check_memory_def( check_memory_spell_c_g_vfx_bgn )
 
 /**/
 
+reg_spell_t	g_reg_spell[MBR_MAX_N];
+check_memory_def( check_memory_spell_c_g_reg_spell )
+
+/**/
+
+#include	"spell-tab.h"
+
+/**/
+
 static mbr_t	*static_cb_menu_sel_spell__pre_sel_mbr;
 
 /**/
@@ -152,6 +161,13 @@ void	init_spell( void )
 				MSG( ls[i].n_msg ),
 				tab->mp, tab->hp, tab->gold );
 	}
+
+	for( m = 0; m < MBR_MAX_N; m++ ){
+		g_reg_spell[m].tab = NULL;
+		g_reg_spell[m].extent_kind = EXTENT_KIND_NORMAL;
+		g_reg_spell[m].trgt.kind = TRGT_KIND_NULL;
+		g_reg_spell[m].trgt.p = NULL;
+	}
 }
 
 /***************************************************************
@@ -263,7 +279,6 @@ void	init_spell_dflt( void )
 
 	m = LS_MBR_N_BEAUT;
 	cast_tab[m][SPELL_KIND_LIGHT].flg_cast = TRUE;
-	cast_tab[m][SPELL_KIND_STORE_LIGHT].flg_cast = TRUE;
 }
 
 /**/
@@ -281,6 +296,20 @@ void	init_spell_nin( void )
 
 /**/
 
+void	reset_spell( void )
+{
+	long	m;
+
+	for( m = 0; m < MBR_MAX_N; m++ ){
+		g_reg_spell[m].tab = NULL;
+		g_reg_spell[m].extent_kind = EXTENT_KIND_NORMAL;
+		g_reg_spell[m].trgt.kind = TRGT_KIND_NULL;
+		g_reg_spell[m].trgt.p = NULL;
+	}
+}
+
+/**/
+
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
 	mbr_t	*pre_sel_mbr;
@@ -337,6 +366,7 @@ char	*menu_sel_spell( mbr_t *mbr )
 	unsigned char	key;
 	bool_t	flg;
 	bool_t	flg_learn;
+	reg_spell_t	*reg;
 	long	i;
 
 	if( mbr == NULL )
@@ -350,6 +380,8 @@ char	*menu_sel_spell( mbr_t *mbr )
 	ls = ls_menu_spell;
 	clr_flg_menu( ls, NULL, FLG_MENU_ALL );
 
+	reg = get_reg_spell( mbr->mbr_n );
+
 	flg_learn = FALSE;
 	key = 'A';
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
@@ -361,7 +393,34 @@ char	*menu_sel_spell( mbr_t *mbr )
 			key = 'A';
 			continue;
 		}
-		if( ls[i].accel_key == 'Z' ){
+		if( ls[i].accel_key == ACCEL_KEY_REG_SPELL ){
+			if( (reg != NULL) && (reg->tab != NULL)
+					&& (reg->trgt.p != NULL) ){
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL,
+						reg->tab->name );
+			} else {
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_NULL );
+			}
+			continue;
+		}
+		if( ls[i].accel_key == ACCEL_KEY_REG_SPELL_REMARK ){
+			if( (reg != NULL) && (reg->tab != NULL) ){
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_REMARK,
+						reg->tab->name );
+			} else {
+				sn_printf( ls[i].msg,
+						MENU_MSG_MAX_BYTE,
+						MSG_MENU_REG_SPELL_NULL );
+			}
+			continue;
+		}
+		if( ls[i].accel_key == ACCEL_KEY_NO_LEARN ){
 			if( flg_learn )
 				ls[i].flg |= FLG_MENU_HIDDEN;
 			else
@@ -454,6 +513,133 @@ char	*menu_sel_spell( mbr_t *mbr )
 
 /**/
 
+char	*cb_menu_reg_spell( menu_t **pp, menu_t **dflt )
+{
+	mbr_t	*mbr;
+	long	mbr_n;
+	void	*p;
+
+	mbr = g_sel_mbr;
+	if( mbr == NULL )
+		return STR_MENU_CANCEL;
+
+	mbr_n = mbr->mbr_n;
+	if( mbr_n < 0 )
+		return STR_MENU_CANCEL;
+	if( mbr_n >= MBR_MAX_N )
+		return STR_MENU_CANCEL;
+
+	p = g_reg_spell[mbr_n].trgt.p;
+	if( p == NULL )
+		return STR_MENU_CANCEL;
+
+	if( g_reg_spell[mbr_n].tab == NULL )
+		return STR_MENU_CANCEL;
+	if( g_reg_spell[mbr_n].trgt.kind == TRGT_KIND_NULL )
+		return STR_MENU_CANCEL;
+
+	/* ˥塼ΥǥեȤ */
+
+	g_dflt_spell_abl[mbr->ls_mbr_n] = *pp;
+
+	/* åȤޡ */
+
+	switch( g_reg_spell[mbr_n].trgt.kind ){
+	case TRGT_KIND_NULL:
+	case TRGT_KIND_AUTO:
+	case TRGT_KIND_MAX_N:
+		return STR_MENU_ERR;
+	case TRGT_KIND_MBR:
+		mark_mbr( mbr, (mbr_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_MNSTR:
+		mark_mnstr( mbr, (mnstr_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_MNSTR_NULL:
+		mark_mnstr_null( mbr,
+				g_reg_spell[mbr_n].trgt.x,
+				g_reg_spell[mbr_n].trgt.y,
+				DIST_FAR );
+		break;
+	case TRGT_KIND_POS:
+		mark_pos( mbr,
+				g_reg_spell[mbr_n].trgt.x,
+				g_reg_spell[mbr_n].trgt.y,
+				DIST_FAR );
+		break;
+	case TRGT_KIND_ITEM:
+		mark_item( mbr, (item_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_DOOR:
+		mark_door( mbr, (door_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_TRAP:
+		mark_trap( mbr, (trap_t *)p, DIST_FAR );
+		break;
+	case TRGT_KIND_QUEUE:
+		return STR_MENU_ERR;
+	case TRGT_KIND_SQUARE:
+		mark_square( mbr );
+		break;
+	}
+
+	/*  */
+
+	set_chr_act( mbr, ACT_KIND_SPELL,
+			g_reg_spell[mbr_n].tab, NULL,
+			g_reg_spell[mbr_n].extent_kind, 0 );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_reg_spell_remark( menu_t **pp, menu_t **dflt )
+{
+	mbr_t	*mbr;
+	long	mbr_n;
+
+	mbr = g_sel_mbr;
+	if( mbr == NULL )
+		return STR_MENU_CANCEL;
+
+	mbr_n = mbr->mbr_n;
+	if( mbr_n < 0 )
+		return STR_MENU_CANCEL;
+	if( mbr_n >= MBR_MAX_N )
+		return STR_MENU_CANCEL;
+
+	if( g_reg_spell[mbr_n].tab == NULL )
+		return STR_MENU_CANCEL;
+	if( g_reg_spell[mbr_n].trgt.kind == TRGT_KIND_NULL )
+		return STR_MENU_CANCEL;
+
+	/* ˥塼ΥǥեȤ */
+
+	g_dflt_spell_abl[mbr->ls_mbr_n] = *pp;
+
+	/* åȤޡ */
+
+	if( get_spell_flg_trgt( g_sel_spell,
+			g_reg_spell[mbr_n].extent_kind ) ){
+		char	*str_goto;
+
+		str_goto = menu_spell_trgt( g_sel_mbr );
+		if( str_goto != NULL )
+			return str_goto;
+	}
+
+	/*  */
+
+	set_chr_act( mbr, ACT_KIND_SPELL,
+			g_reg_spell[mbr_n].tab, NULL,
+			g_reg_spell[mbr_n].extent_kind, 0 );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_dflt_spell_mag( menu_t **pp, menu_t **dflt )
 {
 	return menu_dflt_spell( pp, dflt, ABL_KIND_MAG );
@@ -595,7 +781,6 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 {
 	extent_kind_t	ex;
-	bool_t	flg_trgt;
 
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
@@ -606,22 +791,7 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 	ex = (extent_kind_t)(long)((*pp)->arg);
 
-	flg_trgt = FALSE;
-	if( g_sel_spell->flg_trgt )
-		flg_trgt = TRUE;
-	do {
-		if( g_sel_spell->kind < SPELL_KIND_BAR_MIN_N )
-			break;
-		if( g_sel_spell->kind > SPELL_KIND_BAR_MAX_N )
-			break;
-		if( ex != EXTENT_KIND_NORMAL )
-			break;
-
-		flg_trgt = FALSE;
-		break;
-	} while( 0 );
-
-	if( flg_trgt ){
+	if( get_spell_flg_trgt( g_sel_spell, ex ) ){
 		char	*str_goto;
 
 		str_goto = menu_spell_trgt( g_sel_mbr );
@@ -638,6 +808,27 @@ char	*cb_menu_spell_extent( menu_t **pp, menu_t **dflt )
 
 /**/
 
+bool_t	get_spell_flg_trgt( spell_tab_t *tab, extent_kind_t ex )
+{
+	if( tab == NULL )
+		return FALSE;
+
+	do {
+		if( tab->kind < SPELL_KIND_BAR_MIN_N )
+			break;
+		if( tab->kind > SPELL_KIND_BAR_MAX_N )
+			break;
+		if( ex != EXTENT_KIND_NORMAL )
+			break;
+
+		return FALSE;
+	} while( 0 );
+
+	return( tab->flg_trgt );
+}
+
+/**/
+
 char	*menu_spell_trgt( mbr_t *mbr )
 {
 	pos_t	*crsr;
@@ -756,6 +947,11 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	if( !chk_last_boss_can_spell( tab->kind ) )
 		return;
 
+	if( is_mbr( chr ) ){
+		set_reg_spell( chr->mbr_n, tab,
+				(extent_kind_t)(chr->act.n), chr->trgt );
+	}
+
 	hp = tab->hp;
 	mp = tab->mp;
 	resi = tab->resi_down;
@@ -2393,6 +2589,48 @@ void	counter_magic(
 
 /**/
 
+reg_spell_t	*get_reg_spell( long mbr_n )
+{
+	if( mbr_n < 0 )
+		return NULL;
+	if( mbr_n >= MBR_MAX_N )
+		return NULL;
+
+	return &(g_reg_spell[mbr_n]);
+}
+
+/**/
+
+void	set_reg_spell(
+	long mbr_n,
+	spell_tab_t *tab,
+	extent_kind_t extent_kind,
+	trgt_t trgt
+)
+{
+	if( mbr_n < 0 )
+		return;
+	if( mbr_n >= MBR_MAX_N )
+		return;
+
+	g_reg_spell[mbr_n].tab = tab;
+	g_reg_spell[mbr_n].extent_kind = extent_kind;
+	g_reg_spell[mbr_n].trgt = trgt;
+}
+
+/**/
+
+void	lost_trgt_reg_spell( void *p )
+{
+	long	m;
+
+	for( m = 0; m < MBR_MAX_N; m++ )
+		if( g_reg_spell[m].trgt.p == p )
+			g_reg_spell[m].trgt.p = NULL;
+}
+
+/**/
+
 bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item )
 {
 	abl_kind_t	o_abl, o_sub_abl;
@@ -3704,6 +3942,8 @@ void	check_memory_spell_c( void )
 			"spell.c: g_vfx_n" );
 	check_memory( check_memory_spell_c_g_vfx_bgn,
 			"spell.c: g_vfx_bgn" );
+	check_memory( check_memory_spell_c_g_reg_spell,
+			"spell.c: g_reg_spell" );
 }
 
 /**/
